==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ru/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Этот пользователь может войти в систему',
    'activated_disabled_help_text' => 'Вы не можете редактировать статус активации своей учетной записи.',
    'assets_user'       => 'Актив привязан к :name',
    'bulk_update_warn'	=> 'Вы собираетесь изменить свойства :user_count пользователей. Пожалуйста, обратите внимание, что вы не сможете изменить ваши собственные атрибуты используя эту форму. Если вам нужно изменить атрибуты своего профиля, то внесите изменения отдельно.',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько пользователей за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений.',
    'current_assets'    => 'Активы, выданные данному пользователю',
    'clone'             => 'Клонировать пользователя',
    'contact_user'      => 'Связаться с :name',
    'edit'              => 'Редактировать пользователя',
    'filetype_info'     => 'Разрешенные типы файлов: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История для :name',
	'info'				=> 'Информация',
    'restore_user'		=> 'Нажмите здесь, чтобы восстановить их.',
    'last_login'        => 'Последний вход',
    'ldap_config_text'  => 'Параметры конфигурации LDAP можно найти Администратор > Параметры. Выбранное местоположение будет установлено для всех импортируемых пользователей. (Необязательно).',
    'print_assigned'    => 'Печать всех назначенных',
    'software_user'     => 'Программное обеспечение привязано к :name',
    'send_email_help'   => 'Вы должны указать адрес электронной почты для этого пользователя, чтобы отправить им учетные данные. Электронная почта может быть выполнена только при создании пользователя. Пароли хранятся в одностороннем хэше и не могут быть восстановлены после сохранения.',
    'view_user'         => 'Показать пользователя :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Ваши текущие параметры администрирования разрешают избирательное применение двухфакторной аутентификации.  ',
    'two_factor_enrolled' => 'Устройства для 2-ух факторной аутентификации настроены ',
    'two_factor_active'   => 'Устройства для 2-ух факторной аутентификации активны ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ru/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Этот пользователь может войти в систему',
    'activated_disabled_help_text' => 'Вы не можете редактировать статус активации своей учетной записи.',
    'assets_user'       => 'Актив привязан к :name',
    'bulk_update_warn'	=> 'Вы собираетесь изменить свойства :user_count пользователей. Пожалуйста, обратите внимание, что вы не сможете изменить ваши собственные атрибуты используя эту форму. Если вам нужно изменить атрибуты своего профиля, то внесите изменения отдельно.',
    'bulk_update_help'	=> 'Эта форма позволяет Вам обновить несколько пользователей за раз. Заполняйте только те поля, которые нужно изменить. Пустые поля останутся без изменений.',
    'current_assets'    => 'Активы, выданные данному пользователю',
    'clone'             => 'Клонировать пользователя',
    'contact_user'      => 'Связаться с :name',
    'edit'              => 'Редактировать пользователя',
    'filetype_info'     => 'Разрешенные типы файлов: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, и rar.',
    'history_user'      => 'История для :name',
    'info'				=> 'Информация',
    'restore_user'		=> 'Нажмите здесь, чтобы восстановить их.',
    'last_login'        => 'Последний вход',
    'ldap_config_text'  => 'Параметры конфигурации LDAP можно найти Администратор > Параметры. Выбранное местоположение будет установлено для всех импортируемых пользователей. (Необязательно).',
    'print_assigned'    => 'Печать всех назначенных',
    'software_user'     => 'Программное обеспечение привязано к :name',
    'send_email_help'   => 'Вы должны указать адрес электронной почты для этого пользователя, чтобы отправить им учетные данные. Электронная почта может быть выполнена только при создании пользователя. Пароли хранятся в одностороннем хэше и не могут быть восстановлены после сохранения.',
    'view_user'         => 'Показать пользователя :name',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Ваши текущие параметры администрирования разрешают избирательное применение двухфакторной аутентификации.  ',
    'two_factor_enrolled' => 'Устройства для 2-ух факторной аутентификации настроены ',
    'two_factor_active'   => 'Устройства для 2-ух факторной аутентификации активны ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
